package ch.hslu.appe.inventory.logic.model;

/**
 * Product Reservation.
 */
public final class ProductReservation {

    private static int autoId = 1;
    private int amount;
    private int id;
    private final Object lockObject = new Object();

    private int productNumber;

    /**
     * Default Constructor with ID Generation.
     */
    public ProductReservation() {

        // Generate an id
        synchronized (lockObject) {
            id = autoId++;
        }
    }

    /**
     * Constructor with Default Values.
     * @param productNumber ProductNumber
     * @param amount Amount
     */
    public ProductReservation(final int productNumber, final int amount) {

        this();

        this.productNumber = productNumber;
        this.amount = amount;
    }

    /**
     * Returns the Amount.
     * @return amount
     */
    public int getAmount() {
        return amount;
    }

    /**
     * Returns the ID.
     * @return id
     */
    public int getId() {
        return id;
    }

    /**
     * Returns the ProductNumber.
     * @return productNumber
     */
    public int getProductNumber() {
        return productNumber;
    }

    /**
     * Sets the Amount.
     * @param amount to be set
     */
    public void setAmount(final int amount) {
        this.amount = amount;
    }

    /**
     * Sets the ProductNumber.
     * @param productNumber to be set
     */
    public void setProductNumber(final int productNumber) {
        this.productNumber = productNumber;
    }
}
