package ch.hslu.appe.inventory.webservice;

import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.jws.soap.SOAPBinding.Style;

import ch.hslu.appe.inventory.webservice.dto.ProductDto;

/**
 * Inventory / Stock System Interface für WebService.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
@WebService
@SOAPBinding(style = Style.DOCUMENT)
public interface InventoryService {
    /**
     * Returns a list with all active Products.
     * @return a list with all active Products.
     */
    @WebMethod
    List<ProductDto> getActiveProducts();

    /**
     * Returns a Product based on ProductNumber.
     * @param productNumber requested ProductNumber
     * @return Product
     */
    @WebMethod
    ProductDto getProduct(int productNumber);

    /**
     * Returns a list with all Products.
     * @return a list with all Products.
     */
    @WebMethod
    List<ProductDto> getProducts();

    /**
     * Returns if a Product is active (true) or not (false).
     * @param productNumber requested ProductNumber
     * @return true if active otherwise false
     */
    @WebMethod
    boolean productActive(int productNumber);

    /**
     * Returns if a Product exists (true) or not (false).
     * @param productNumber requested ProductNumber
     * @return true if exists otherwise false
     */
    @WebMethod
    boolean productExists(int productNumber);
}
