package ch.hslu.appe.usermanagement.webservice;

import java.util.List;

import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.jws.soap.SOAPBinding.Style;

import ch.hslu.appe.usermanagement.exception.IllegalNameException;
import ch.hslu.appe.usermanagement.webservice.dto.AddressDto;
import ch.hslu.appe.usermanagement.webservice.dto.UserDto;

/**
 * Usermanagement Service Interface.
 */
@WebService
@SOAPBinding(style = Style.DOCUMENT)
public interface UserManagementService {

    /**
     * Adds a new address entry.
     * @param userId The users id
     * @param address The address
     * @return Returns true on success, otherwise false
     */
    @WebMethod
    boolean addAddress(int userId, AddressDto address);

    /**
     * Adds a new user.
     * @param user The user
     * @return Returns true on success, otherwise false
     * @throws IllegalNameException illegal userName
     */
    @WebMethod
    boolean addUser(UserDto user) throws IllegalNameException;

    /**
     * Deletes an address by its id.
     * @param addressId The address id
     * @return Returns true on success, otherwise false
     */

    @WebMethod
    boolean deleteAddress(int addressId);

    /**
     * Deletes a user by its id.
     * @param userId The user id
     * @return Returns true on success, otherwise false
     */
    @WebMethod
    boolean deleteUser(int userId);

    /**
     * Gets an address by its id.
     * @param addressId The address id
     * @return Returns the address if it exists, otherwise false
     */
    @WebMethod
    AddressDto getAddress(int addressId);

    /**
     * Gets all addresses from a user, looked up by its id.
     * @param userId The user id
     * @return Returns all user addresses
     */
    @WebMethod
    List<AddressDto> getAddressesById(int userId);

    /**
     * Gets all addresses of a login.
     * @param login The login name
     * @return Returns all user addresses
     */
    @WebMethod
    List<AddressDto> getAddressesByLogin(String login);

    /**
     * Gets a user by its id.
     * @param userId The id
     * @return Returns the user if it exists, otherwise null
     */
    @WebMethod
    UserDto getUserById(int userId);

    /**
     * Gets a user by its login name.
     * @param login The login name
     * @return Returns the user if it exists, otherwise null
     */
    @WebMethod
    UserDto getUserByLogin(String login);

    /**
     * Gets a list of user.
     * @return Returns all user which matches the filter
     */
    @WebMethod
    List<UserDto> getUsers();

    /**
     * Alters an existent address.
     * @param address The address
     * @return Returns true on success, otherwise false
     */
    @WebMethod
    boolean updateAddress(AddressDto address);

    /**
     * Alters an existent user.
     * @param user The user
     * @return Returns true on success, otherwise false
     * @throws IllegalNameException IllegalNameException
     */
    @WebMethod
    boolean updateUser(UserDto user) throws IllegalNameException;
}
