package ch.hslu.appe.usermanagement.webservice;

import java.util.ArrayList;
import java.util.List;

import javax.jws.HandlerChain;
import javax.jws.WebService;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;

import ch.hslu.appe.helper.HashHelper;
import ch.hslu.appe.usermanagement.exception.IllegalNameException;
import ch.hslu.appe.usermanagement.logic.UserManagement;
import ch.hslu.appe.usermanagement.logic.UserManagementImpl;
import ch.hslu.appe.usermanagement.model.Address;
import ch.hslu.appe.usermanagement.model.User;
import ch.hslu.appe.usermanagement.webservice.dto.AddressDto;
import ch.hslu.appe.usermanagement.webservice.dto.UserDto;

/**
 * Usermanagement Service Implementation.
 */
@WebService(endpointInterface = "ch.hslu.appe.usermanagement.webservice.UserManagementService")
@HandlerChain(file = "./handler/handlers.xml")
public final class UserManagementServiceImpl implements UserManagementService {

    private final UserManagement userManagement = new UserManagementImpl();

    @Override
    public boolean addAddress(final int userId, final AddressDto address) {

        return userManagement.addAddress(userId, address.toAddress());
    }

    @Override
    public boolean addUser(final UserDto user) throws IllegalNameException {

        if (user.getPassword() == null) {
            user.setPassword("");
        }

        user.setPassword(HashHelper.sha1(user.getPassword(), "hslu"));

        return userManagement.addUser(user.toUser());
    }

    @Override
    public boolean deleteAddress(final int addressId) {

        return userManagement.deleteAddress(addressId);
    }

    @Override
    public boolean deleteUser(final int userId) {

        return userManagement.deleteUser(userId);
    }

    @Override
    public AddressDto getAddress(final int addressId) {

        return AddressDto.fromAddress(userManagement.getAddress(addressId));
    }

    @Override
    @XmlElementWrapper(name = "addresses")
    @XmlElement(name = "address")
    public List<AddressDto> getAddressesById(final int userId) {

        final List<AddressDto> addresses = new ArrayList<AddressDto>();

        for (final Address address : userManagement.getAddresses(userId)) {
            addresses.add(AddressDto.fromAddress(address));
        }

        return addresses;
    }

    @Override
    @XmlElementWrapper(name = "addresses")
    @XmlElement(name = "address")
    public List<AddressDto> getAddressesByLogin(final String login) {

        final List<AddressDto> addresses = new ArrayList<AddressDto>();

        for (final Address address : userManagement.getAddresses(login)) {
            addresses.add(AddressDto.fromAddress(address));
        }

        return addresses;
    }

    @Override
    public UserDto getUserById(final int userId) {

        return UserDto.fromUser(userManagement.getUserById(userId));
    }

    @Override
    public UserDto getUserByLogin(final String login) {

        return UserDto.fromUser(userManagement.getUserByLogin(login));
    }

    @Override
    @XmlElementWrapper(name = "users")
    @XmlElement(name = "user")
    public List<UserDto> getUsers() {

        final List<UserDto> users = new ArrayList<UserDto>();

        for (final User user : userManagement.getUsers(null)) {
            users.add(UserDto.fromUser(user));
        }

        return users;
    }

    @Override
    public boolean updateAddress(final AddressDto address) {

        final Address updatedAddress = address.toAddress();
        final Address currentAddress = userManagement.getAddress(address.getId());

        // Update the user
        if (currentAddress != null) {
            updatedAddress.setUser(currentAddress.getUser());
        }

        return userManagement.updateAddress(updatedAddress);
    }

    @Override
    public boolean updateUser(final UserDto user) throws IllegalNameException {

        if (user.getPassword() == null) {
            user.setPassword("");
        }

        if (!user.getPassword().isEmpty()) {
            user.setPassword(HashHelper.sha1(user.getPassword(), "hslu"));
        }

        return userManagement.updateUser(user.toUser());
    }
}
